#ifndef NT2_INCLUDE_FUNCTIONS_ASIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASIN_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/asin.hpp>

#endif
